#!/bin/bash
cwd=$PWD

function config_workspace()
{	
	terraform init -lock-timeout=120s
	if [[ $? != 0 ]]; then
		echo "terraform init for $1 failed, exiting.";
		return 1;
	fi

	terraform get
	terraform validate
	if [[ $? != 0 ]]; then
		echo "terraform validate for $1 failed, exiting.";
		return 1;
	fi


	terraform workspace select $workspace
	if [[ $? -eq 0 ]]; then
		echo "terraform workspace set to $workspace"
	else
		if [[ $delAMI -eq 1 ]]; then
			echo "terraform workspace $workspace does not exists!"
			exit;
		fi

		echo "new terraform workspace is created with name $workspace"
		terraform workspace new $workspace
	fi

	if [[ $crtAMI -eq 1 ]]; then
		terraform plan -lock-timeout=120s
		if [[ $? != 0 ]]; then
			echo "terraform plan for $1 failed, exiting.";
			return 1;
		fi
	fi
}

function apply()
{
	echo "cd $cwd/$1"
	cd $cwd/$1
	config_workspace

	terraform apply -auto-approve -lock-timeout=60m
	if [[ $? != 0 ]]; then	
		echo "terraform apply failed for $1, destroying all the resources created.";
		terraform destroy -auto-approve -lock-timeout=10m
		return 1;
	fi

	return 0;
}

function destroy()
{
	echo "cd $cwd/$1"
	cd $cwd/$1

	config_workspace
	terraform destroy -auto-approve -lock-timeout=10m
	if [[ $? != 0 ]]; then	
		echo "terraform destroy failed for $1, exiting.";
		return 1;
	fi

	return 0;
}


function deleteAMI()
{
	destroy "ami"
	destroy "linuxvm"
}

#On success return 0 and otherwise 1
function createAMI()
{
	#first configure workspace for linuxvm stack, to create linux vm and a 20GB volume
        echo "Applying linuxvm stack"
	apply "linuxvm"
	if [[ $? -ne 0 ]]; then
		rc=1
		return $rc;
	fi

	#later configure workspace for ami stack to create Snapshot and AMI out of 20GB volume
        echo "Applying ami stack"
	apply "ami"
	if [[ $? -eq 0 ]]; then
		rc=0
	else
		rc=1
	fi

	echo "Destroying interrim resources used to create the AMI"
	destroy "linuxvm"

	return $rc;
}

function helpFunction()
{
   echo ""
   echo "Usage: bash $0 <-c|-d> <workspace name>"
   echo ""
   echo "Options:"
   echo -e "\t-c Create(or Select) a workspace and AMI"
   echo -e "\t-d Delete an AMI and other resources" 
   exit 1 # Exit script after printing help
}


while getopts "c:d:" opt
do
   case "$opt" in
      d ) workspace="$OPTARG"; delAMI=1 ;;
      c ) workspace="$OPTARG"; crtAMI=1 ;;
      ? ) helpFunction ;; # Print helpFunction in case parameter is non-existent
   esac
done

if [[ -z "$workspace" ]]; then
	printf "\n***  Invalid input\n";
	helpFunction;
	exit
fi

if [[ $crtAMI -eq 1 ]]; then
#	echo "createAMI"
	createAMI
	if [[ "$?" == "0" ]]; then
		echo "Successfully created the AMI"
		cd $cwd/ami
		terraform output
	else
		echo "Failed to create the AMI"
	fi
	exit
fi

if [[ $delAMI -eq 1 ]]; then
#	echo "deleteAMI"
	deleteAMI
	exit
fi
