/*************************************************************/
// Copyright (c) 2020 Oracle and/or its affiliates.
/*************************************************************/


// VCN creation and same will be mapped to all the resource created as part of vcn stack
resource "oci_core_vcn" "sbc_vcn" {
  compartment_id = var.compartment_ocid
  cidr_block     = var.vcn_cidr
  dns_label      = var.resource_label
  display_name   = "${var.resource_label}-vcn"
}

// Wancom0 subnet creation

resource "oci_core_subnet" "sbc_subnet_mgmt_wancom0" {
  compartment_id             = var.compartment_ocid
  cidr_block                 = var.subnet_cidr_wancom_0
  prohibit_public_ip_on_vnic = var.prohibit_public_ip_management
  vcn_id                     = oci_core_vcn.sbc_vcn.id
  route_table_id             = oci_core_route_table.sbc_mgmt_routetable.id
  security_list_ids          = [oci_core_security_list.sbc_mgmt_security_list.id]
  display_name               = "${var.resource_label}-subnet_mgmt_wancom0"
}

// Wancom1 subnet creation
resource "oci_core_subnet" "sbc_subnet_mgmt_wancom1" {
  compartment_id             = var.compartment_ocid
  cidr_block                 = var.subnet_cidr_wancom_1
  prohibit_public_ip_on_vnic = true
  vcn_id                     = oci_core_vcn.sbc_vcn.id
  security_list_ids          = [oci_core_security_list.sbc_mgmt_security_list.id]
  display_name               = "${var.resource_label}-subnet_ha_wancom1"
}

// Wancom2 subnet creation
resource "oci_core_subnet" "sbc_subnet_mgmt_wancom2" {
  compartment_id             = var.compartment_ocid
  cidr_block                 = var.subnet_cidr_wancom_2
  prohibit_public_ip_on_vnic = true
  vcn_id                     = oci_core_vcn.sbc_vcn.id
  security_list_ids          = [oci_core_security_list.sbc_mgmt_security_list.id]
  display_name               = "${var.resource_label}-subnet_ha_wancom2"
}

// Media subnet s0p0 creation
resource "oci_core_subnet" "sbc_subnet_media_s0p0" {
  compartment_id             = var.compartment_ocid
  cidr_block                 = var.subnet_cidr_media_s0p0
  prohibit_public_ip_on_vnic = var.prohibit_public_ip_media
  route_table_id             = oci_core_route_table.sbc_media_routetable.id
  vcn_id                     = oci_core_vcn.sbc_vcn.id
  security_list_ids          = [oci_core_security_list.media_security_list.id]
  display_name               = "${var.resource_label}-media_s0p0"
}


// Media subnet s1p0 creation
resource "oci_core_subnet" "sbc_subnet_media_s1p0" {
  compartment_id             = var.compartment_ocid
  cidr_block                 = var.subnet_cidr_media_s1p0
  vcn_id                     = oci_core_vcn.sbc_vcn.id
  prohibit_public_ip_on_vnic = var.prohibit_public_ip_media
  route_table_id             = oci_core_route_table.sbc_media_routetable.id
  security_list_ids          = [oci_core_security_list.media_security_list.id]
  display_name               = "${var.resource_label}-media_s1p0"
}

// Media subnet s0p1 creation
resource "oci_core_subnet" "sbc_subnet_media_s0p1" {
  compartment_id             = var.compartment_ocid
  cidr_block                 = var.subnet_cidr_media_s0p1
  prohibit_public_ip_on_vnic = var.prohibit_public_ip_media
  route_table_id             = oci_core_route_table.sbc_media_routetable.id
  vcn_id                     = oci_core_vcn.sbc_vcn.id
  security_list_ids          = [oci_core_security_list.media_security_list.id]
  display_name               = "${var.resource_label}-media_s0p1"
}

// Media subnet s1p1 creation
resource "oci_core_subnet" "sbc_subnet_media_s1p1" {
  compartment_id             = var.compartment_ocid
  cidr_block                 = var.subnet_cidr_media_s1p1
  prohibit_public_ip_on_vnic = var.prohibit_public_ip_media
  route_table_id             = oci_core_route_table.sbc_media_routetable.id
  vcn_id                     = oci_core_vcn.sbc_vcn.id
  security_list_ids          = [oci_core_security_list.media_security_list.id]
  display_name               = "${var.resource_label}-media_s1p1"
}

//To fetch namspace id
data "oci_objectstorage_namespace" "ns" {
  compartment_id = var.compartment_ocid
}


// Bucket creation (optional)
resource "oci_objectstorage_bucket" "test_bucket" {
  count          = var.create_bucket == true ? 1 : 0
  compartment_id = var.compartment_ocid
  name           = var.bucket_name
  namespace      = data.oci_objectstorage_namespace.ns.namespace
}
